searchData={"items":[{"type":"module","title":"NervesLogging","doc":"NervesLogging forwards log messages from the Linux kernel and syslog to the Elixir logger\n\nLog messages have the following additional metadata:\n\n* `:facility` - the facility of the log message\n* `:application` - either `:$kmsg` or `:$syslog`\n\nSee the [Elixir Logger documentation](https://hexdocs.pm/logger/Logger.html) for\nreducing what's logged if the system logs become too noisy. Some examples:\n\n```elixir\n# Reduce logging for both syslog and kernel logs\nLogger.put_application_level(:nerves_logging, :error)\n\n# Adjust logging for kernel logs\nLogger.put_module_level(NervesLogging.KmsgTailer, :error)\n\n# Adjust logging for syslog logs\nLogger.put_module_level(NervesLogging.SyslogTailer, :error)\n```","ref":"NervesLogging.html"},{"type":"type","title":"NervesLogging.facility/0","doc":"Syslog facilities\n\nSee https://tools.ietf.org/html/rfc5424#section-6.2.1 for the list.","ref":"NervesLogging.html#t:facility/0"},{"type":"type","title":"NervesLogging.severity/0","doc":"Syslog severity levels\n\nThese map 1:1 to `Logger.level/0` values.","ref":"NervesLogging.html#t:severity/0"},{"type":"extras","title":"NervesLogging","doc":"# NervesLogging\n\n[![Hex version](https://img.shields.io/hexpm/v/nerves_logging.svg \"Hex version\")](https://hex.pm/packages/nerves_logging)\n[![API docs](https://img.shields.io/hexpm/v/nerves_logging.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/nerves_logging/NervesLogging.html)\n[![CircleCI](https://circleci.com/gh/nerves-project/nerves_logging.svg?style=svg)](https://circleci.com/gh/nerves-project/nerves_logging)\n[![REUSE status](https://api.reuse.software/badge/github.com/nerves-project/nerves_logging)](https://api.reuse.software/info/github.com/nerves-project/nerves_logging)\n\nNervesLogging forwards log messages from the Linux kernel and syslog to the\nElixir logger. It's used with Nerves so that all log messages pass through one\nplace.\n\nMessages logged by NervesLogging copy the \"Syslog\" severity directly to the\nLogger level. This means that if the kernel's level is \"Error\", the Elixir level\nwill be `:error`. Since Elixir 1.11 and later have the same log levels as\nSyslog, this mapping is 1:1.\n\nNervesLogging adds the following metadata to the log messages:\n\n* `:facility` - the facility of the log message\n* `:application` - either `:$kmsg` or `:$syslog`\n\nSee the [Elixir Logger documentation](https://hexdocs.pm/logger/Logger.html) for\nreducing what's logged if the system logs become too noisy. Some examples:\n\n```elixir\n# Reduce logging for both syslog and kernel logs\nLogger.put_application_level(:nerves_logging, :error)\n\n# Adjust logging for kernel logs\nLogger.put_module_level(NervesLogging.KmsgTailer, :error)\n\n# Adjust logging for syslog logs\nLogger.put_module_level(NervesLogging.SyslogTailer, :error)\n```","ref":"readme.html"},{"type":"extras","title":"Using - NervesLogging","doc":"There's no configuration. If you're using Nerves, you should get this\napplication by default since it's a dependency of\n[nerves_runtime](https://github.com/nerves-project/nerves_runtime).","ref":"readme.html#using"},{"type":"extras","title":"License - NervesLogging","doc":"All original source code in this project is licensed under Apache-2.0.\n\nAdditionally, this project follows the [REUSE recommendations](https://reuse.software)\nand labels so that licensing and copyright are clear at the file level.\n\nExceptions to Apache-2.0 licensing are:\n\n* Configuration and data files are licensed under CC0-1.0\n* Documentation is CC-BY-4.0","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.3 - 2025-04-10 - Changelog","doc":"* Changes\n  * Fix log message metadata and logging function call so log filtering works as\n    documented. This also improves the docs.\n  * General documentation and public API cleanup. This removes log parsing\n    modules from the public API since they're not intended to be called\n    directly.","ref":"changelog.html#v0-2-3-2025-04-10"},{"type":"extras","title":"v0.2.2 - 2023-11-05 - Changelog","doc":"* Changes\n  * Label log messages coming from syslog and the kernel ringbuffer as `$syslog`\n    and `$kmsg`. These are in the \"application\" field. This helps when log\n    messages by application since these used to be `nil`.","ref":"changelog.html#v0-2-2-2023-11-05"},{"type":"extras","title":"v0.2.1 - 2023-06-30 - Changelog","doc":"* Changes\n  * Fix Elixir 1.15 Logger warning","ref":"changelog.html#v0-2-1-2023-06-30"},{"type":"extras","title":"v0.2.0 - 2022-07-04 - Changelog","doc":"* Changes\n  * No longer automatically start log tailers. Users must add\n    `NervesLogging.KmsgTailer` and `NervesLogging.SyslogTailer` to their\n    supervision trees. This simplifies the logic for whether to start the\n    loggers or not. Very few users will need to do anything. It will be handled\n    by `Nerves.Runtime`.","ref":"changelog.html#v0-2-0-2022-07-04"},{"type":"extras","title":"v0.1.1 - 2022-06-03 - Changelog","doc":"* Changes\n  * Don't crash when lacking permissions to read logs. Restarting doesn't fix\n    the permission issue so this ends up being terminal. The error will be\n    logged.","ref":"changelog.html#v0-1-1-2022-06-03"},{"type":"extras","title":"v0.1.0 - 2022-04-26 - Changelog","doc":"Extract system logging from `nerves_runtime`.\n\n* Updates\n  * Require Elixir 1.11 and remove all syslog-to-Elixir log level conversion code\n    since Elixir accepts all of the syslog levels now.\n  * Remove the `:severity` field from log messages since it's redundant now.\n    It's unknown if this field was actually used.","ref":"changelog.html#v0-1-0-2022-04-26"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}